==> carbon-simulator-2.0.tar.gz: carbon-simulator-2.0/carbon/tests/nbtest/test_0000_TestNotebook.py <==
# ------------------------------------------------------------
# Auto generated test file `test_0000_TestNotebook.py`
# ------------------------------------------------------------
# source file   = NBTest_0000_TestNotebook.py
# source path   = /Users/skl/REPOES/Bancor/CarbonSimulator/resources/NBTest/
# target path   = /Users/skl/REPOES/Bancor/CarbonSimulator/resources/NBTest/
# test id       = 0000
# test comment  = TestNotebook
# ------------------------------------------------------------



import pandas as pd


#
#
#
#
#
#


# ------------------------------------------------------------
# Test      0000
# File      test_0000_TestNotebook.py
# Segment   Segment 1
# ------------------------------------------------------------
def test_segment_1():
# ------------------------------------------------------------
    
    assert True
    

# ------------------------------------------------------------
# Test      0000
# File      test_0000_TestNotebook.py
# Segment   Segment 2
# ------------------------------------------------------------
def test_segment_2():
# ------------------------------------------------------------
    
    assert True
    

# ------------------------------------------------------------
# Test      0000
# File      test_0000_TestNotebook.py
# Segment   Segment 3 [NOTEST]
# ------------------------------------------------------------
def notest_segment_3():
# ------------------------------------------------------------
    
    # This segment will not be used to create a test (the function will still be generated, but it will be prefixed with `notest` rather than `test`)
    
    assert False

==> carbon-simulator-2.2.3.tar.gz: carbon-simulator-2.2.3/carbon/tests/nbtest/test_0000_TestNotebook.py <==
# ------------------------------------------------------------
# Auto generated test file `test_0000_TestNotebook.py`
# ------------------------------------------------------------
# source file   = NBTest_0000_TestNotebook.py
# source path   = /Users/skl/REPOES/Bancor/CarbonSimulator/resources/NBTest/
# target path   = /Users/skl/REPOES/Bancor/CarbonSimulator/resources/NBTest/
# test id       = 0000
# test comment  = TestNotebook
# ------------------------------------------------------------



import pandas as pd


#
#
#
#
#
#

#
#



# ------------------------------------------------------------
# Test      0000
# File      test_0000_TestNotebook.py
# Segment   Segment 1
# ------------------------------------------------------------
def test_segment_1():
# ------------------------------------------------------------
    
    assert True
    

# ------------------------------------------------------------
# Test      0000
# File      test_0000_TestNotebook.py
# Segment   Segment 2 [TEST]
# ------------------------------------------------------------
def test_segment_2():
# ------------------------------------------------------------
    
    assert True
    

# ------------------------------------------------------------
# Test      0000
# File      test_0000_TestNotebook.py
# Segment   Segment 3 [NOTEST]
# ------------------------------------------------------------
def notest_segment_3():
# ------------------------------------------------------------
    
    # This segment will not be used to create a test (the function will still be generated, but it will be prefixed with `notest` rather than `test`)
    
    assert False
